require "logger"
require "rollbar"

class RollbarLogger < Logger
  VERSION = [
    VERSION_MAJOR = 1,
    VERSION_MINOR = 0,
    VERSION_TINY = 1,
    VERSION_PRE = nil
  ].compact.join(".")

  class Error < RuntimeError; end
  class DatetimeFormatNotSupported < Error; end
  class FormatterNotSupported < Error; end

  def initialize
    @level = DEBUG
    @logdev = nil

    Rollbar.configuration.logger = Logger.new("/dev/null")
  end

  def formatter=(formatter)
    raise(FormatterNotSupported)
  end

  def formatter
    raise(FormatterNotSupported)
  end

  def datetime_format=(datetime_format)
    raise(DatetimeFormatNotSupported)
  end

  def datetime_format
    raise(DatetimeFormatNotSupported)
  end

  def <<(message)
    error(message)
  end

  def add(severity, message = nil, progname = nil, &block)
    severity ||= FATAL
    severity = FATAL if severity == UNKNOWN
    message ||= block_given? ? yield : progname

    return true if severity < @level

    Rollbar.log(rollbar_level(severity), message)
  end

  private

  def rollbar_level(severity)
    [:debug, :info, :warning, :error, :critical, :error][severity] || :error
  end
end
